//
//
// Version:  4.33.0
//
// Author:   korvtiger
//
// Template för ånglok som använder sig av STLs ångloksscript.
// Se separat dokument för närmare detaljer.
//
// ****************************************************************************************************

include "stlSteamEngine.gs"

// ====================================================================================================

class ***ClassName*** isclass STLSteamEngine {
	
	
	public void Init(void) {
		inherited(); // Anropa STLSteamEngines Init, ha ingen kod ovan detta anrop!
		
		// Koppla olika funktioner i scriptet till rätt smoke PFX ID. Nummren är samma som de har i configen i namnet, ex. smoke10 har ID=10
		// Ta bort de som inte är relevanta för loktypen
		
		//SMOKE_ID_INJECTOR_LEFT = 3;			// 3 och 4 är standardvärden som ej behöver sättas. Kan tas bort (= -1) eller ändras om 
		//SMOKE_ID_INJECTOR_RIGHT = 4;			// man inte önskar rök när injektorerna suger, eller om man vill använda andra smoke-id:n
		
		// Ta bort de som inte är relevanta, eller sätt deras värde till -1 (standardvärden är -1)
		// Exempel:
		SMOKE_ID_STEAM_HEAT_SAFETY = 18;		// Smoke ID till ångvärmens säkerhetsventil
		SMOKE_ID_TURBO_GENERATOR = 19;			// Smoke ID till turbogeneratorn
		SMOKE_ID_STEAM_BRAKE = 20;				// Smoke ID till ångbromsen
		
		// Ta bort de som inte är relevanta, eller sätt deras värde till "" (standardvärden är "")
		// Exempel:
		SMOKE_ID_SAND_FRONT_ON = "+10+12";		// Smoke IDn till rökeffekterna som ska vara på vid sandning framför hjulen
		SMOKE_ID_SAND_BACK_ON = "+11+13";		// Smoke IDn till rökeffekterna som ska vara på vid sandning bakom hjulen (i regel enbart på tanklok)
		SMOKE_ID_PYSARE_ON = "+14+15+16+17";	// Smoke IDn till pysarna
		SMOKE_ID_AIR_PUMP_ON = "+21";			// Smoke IDn till luftpumpen (kan användas både som avlopp ur skorstenen och läckage runt pumpen)
		SMOKE_ID_CYLINDER_LEAK_ON = "+22+23";	// Smoke IDn till läckage runt cylindrarna, slås på när det är tryck i cylindrarna.
	
		
		
		
		// Sätt gränsvärden för olika smoke PFX attribut som är styrda av scriptet. Se det separata dokumentet för närmare förklaring.
		// Dessa värden är standardvärden och kan därför kommenteras bort för alla värden som inte ändras.
	
		blowerDark.SetValues(23.0, 24.0, 24.0, 230.0); 		// RGBA för sotarens rök som mörkast
		blowerLight.SetValues(210.0, 220.0, 220.0, 180.0);	// RGBA för sotarens rök som ljusast
		stackDark.SetValues(73.0, 64.0, 54.0, 130.0);		// RGBA för skorstenens rök som mörkast
		stackLight.SetValues(182.0, 191.0, 201.0, 220.0);	// RGBA för skorstenens rök som ljusast
	
		// Talar om för scriptet att det får modifiera attributet mellan Base och Base+Factor
		// Attributen har samma namn som i configen
		stackMaxSizeBase = 1.0;			// Styr attributet max size hos skorstensröken
	    stackMaxSizeFactor = 5.0;
		
	    stackVelocityBase = 15.0;		// Styr attributet velocity hos skorstensröken (i m/s)
	    stackVelocityFactor = 10.0;
		
	    blowerMinSizeBase = 0.35;		// Styr attributet min size hos sotaren
	    blowerMinSizeFactor = 0.15;
		
	    blowerMaxSizeBase = 1.0;		// Styr attributet max size hos sotaren
	    blowerMaxSizeFactor = 1.0;
		
	    blowerVelocityBase = 1.0;		// Styr attributet velocity hos sotaren (i m/s)
	    blowerVelocityFactor = 9.0;
		
	    blowerLifetimeBase = 0.5;		// Styr attributet lifetime hos sotaren (i sek)
	    blowerLifetimeFactor = 3.0;
		
	    pysareMaxSizeBase = 0.3;		// Styr attributet max size hos pysaren
	    pysareMaxSizeFactor = 0.7;
		
	    pysareVelocityBase = 0.5;		// Styr attributet velocity hos pysaren
	    pysareVelocityFactor = 3.5;
	}

	
	/**
	 * This method is supposed to be overridden by user script to provide custom script functionality.
	 * This method is called by the update thread every 1.5 - 2.5 seconds to update the loco.
	 * Params: exhaustSteam	"Amount" of exhaust steam from the cylinders currently throught the chimney on a scale from 0.0 to 1.0.
	 */
	void SteamThreadUpdate(float exhaustSteam) {
	
	}
	
	
	/**
	 * This method is intended to be overridden by the user code whenever properties should be editable in the Driver module.
	 */
	string GetDriverDescriptionHTML(string html) {
		// En metod där man kan lägga till text i propertyrutan i Driver. Denna fungerar på exakt samma sätt som GetDescriptionHTML(void) fungerar för Surveyor.
		// Notera dock att enbart PropertyType "link" fungerar i Driver. Samma GetPropertyType LinkPropertyValue osv. metoder kommer att anropas som i Surveyor.
		
		// Exempel:
		html = html + "Lite <a href=live://property/some_link_name>tryckbar text</a> som bara syns i propertyrutan i Driver-modulen.\n";
		return html;
	}
	
	
	// Metod som kan anropas på en STLSteamEngine för att lokalisera en tillkopplad tender. Returnerar null om ingen tender kunnde hittas.
	// Vehicle GetMyTender();
	
};
